@@ -33,6 +33,9 @@
 #include <glibmm/i18n.h>
 
 
+namespace Glom
+{
+
 App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Window(cobject), //It's a virtual base class, so we have to call the specific constructor to prevent the default constructor from being called.
   type_base(cobject, "Glom"),
@@ -42,8 +45,15 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml
   m_menu_tables_ui_merge_id(0),
   m_menu_reports_ui_merge_id(0)
 {
-  //Show the icon in the window manager's window title bar and in the list of running applications:
-  set_icon_from_file(GLOM_ICON_DIR "/glom.png");
+  try
+  {
+    //Show the icon in the window manager's window title bar and in the list of running applications:
+    set_icon_from_file(GLOM_ICON_DIR "/glom.png");
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << "App_Glom::App_Glom(): Could not set icon: " << ex.what() << std::endl;
+  } 
 
   //Load widgets from glade file:
   refGlade->get_widget("bakery_vbox", m_pBoxTop);
@@ -676,7 +686,7 @@ bool App_Glom::offer_new_or_existing()
 
           //Set suitable defaults:
           const Glib::ustring filename = document->get_name(); //Get the filename without the path and extension.
-          dialog->set_input( Base_DB::util_title_from_string( filename ) ); //Start with something suitable.
+          dialog->set_input( Utils::title_from_string( filename ) ); //Start with something suitable.
 
           bool keep_asking = true;
           while(keep_asking)
@@ -690,7 +700,7 @@ bool App_Glom::offer_new_or_existing()
 
               //Create a database name based on the title.
               //The user will (almost) never see this anyway but it's nicer than using a random number:
-              Glib::ustring db_name = GlomUtils::create_name_from_title(db_title);
+              Glib::ustring db_name = Utils::create_name_from_title(db_title);
 
               //Prefix glom_ to the database name, so it's more obvious
               //for the system administrator.
@@ -837,7 +847,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
     if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
     {
       user_cancelled = true; //Eventually, the user will cancel after retrying.
-      g_warning("App_Glom::recreate_database(): Failed because connection to server failed, without specifying a databse.");
+      g_warning("App_Glom::recreate_database(): Failed because connection to server failed, without specifying a database.");
       return false;
     }
 
@@ -869,7 +879,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
 
   //Create the database: (This will show a connection dialog)
   connection_pool->set_database( Glib::ustring() );
-  bool db_created = m_pFrame->create_database(db_name, pDocument->get_database_title(), false /* Don't ask for password etc again. */);
+  const bool db_created = m_pFrame->create_database(db_name, pDocument->get_database_title(), false /* Don't ask for password etc again. */);
 
   if(!db_created)
   {
@@ -999,7 +1009,7 @@ void App_Glom::fill_menu_tables()
 
       ui_description += "<menuitem action='" + action_name + "' />";
 
-      Glib::RefPtr<Gtk::Action> refAction = Gtk::Action::create(action_name, GlomUtils::string_escape_underscores(table_info->get_title_or_name()));
+      Glib::RefPtr<Gtk::Action> refAction = Gtk::Action::create(action_name, Utils::string_escape_underscores(table_info->get_title_or_name()));
       m_refNavTablesActionGroup->add(refAction,
         sigc::bind( sigc::mem_fun(*m_pFrame, &Frame_Glom::on_box_tables_selected), table_info->get_name()) );
 
@@ -1062,7 +1072,7 @@ void App_Glom::fill_menu_reports(const Glib::ustring& table_name)
 
         ui_description += "<menuitem action='" + action_name + "' />";
 
-        Glib::RefPtr<Gtk::Action> refAction = Gtk::Action::create( action_name, GlomUtils::string_escape_underscores(report->get_title_or_name()));
+        Glib::RefPtr<Gtk::Action> refAction = Gtk::Action::create( action_name, Utils::string_escape_underscores(report->get_title_or_name()));
         m_refNavReportsActionGroup->add(refAction,
           sigc::bind( sigc::mem_fun(*m_pFrame, &Frame_Glom::on_menu_report_selected), report->get_name()) );
 
@@ -1264,4 +1274,6 @@ void App_Glom::on_window_translations_hide()
 }
 
 
+} //namespace Glom
+
 
