@@ -22,6 +22,9 @@
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Box_DB(cobject),
   m_pLabelFrameTitle(0),
@@ -240,7 +243,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 
     sharedptr<TableInfo> table_info(new TableInfo());
     table_info->set_name(table_name);
-    table_info->set_title( util_title_from_string( table_name ) ); //Start with a title that might be appropriate.
+    table_info->set_title( Utils::title_from_string( table_name ) ); //Start with a title that might be appropriate.
 
     //Check whether it exists already. (Maybe it is somehow in the database but not in the document. That shouldn't happen.)
     const bool exists_in_db = get_table_exists_in_database(table_name);
@@ -385,6 +388,8 @@ void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 
 void Box_Tables::save_to_document()
 {
+  std::cout << "debug: Box_Tables::save_to_document" << std::endl;
+
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     //Save the hidden tables. TODO_usermode: Only if we are in developer mode.
@@ -398,6 +403,7 @@ void Box_Tables::save_to_document()
       sharedptr<TableInfo> table_info = document->get_table(table_name); //Start with the existing table_info, to preserve extra information, such as translations.
       if(table_info)
       {
+        std::cout << "  debug: table=" << m_AddDel.get_value(iter, m_colTableName) << std::endl;
         table_info->set_name( m_AddDel.get_value(iter, m_colTableName) );
 
         if(!table_info->get_name().empty())
@@ -474,3 +480,5 @@ void Box_Tables::on_userlevel_changed(AppState::userlevels /* userlevel */)
 {
   fill_from_database();
 }
+
+} //namespace Glom
